<?php

/*
 * Generates the FS Form
 * Author: Rudyard Murdough
 */
class FsFormViewValue
{
    public $name;
    public $value;
}
class FsFormView
{
    private static $TextInputType = 1;
    private static $TextAreaType = 2;
    private static $CheckInputsType = 3;
    private static $RadioInputsType = 4;
    private static $DateInputType = 5;
    
    public static $InsideLabelType = 1;
    public static $OutsideLabelType = 2;
    
    private $template = null;
    private $required_marker;
    
    public function __construct()
    {
        add_shortcode( 'fs_form', array(&$this, 'RenderForm' ));   
    }
    
    function RenderForm($atts)
    {        
	extract( shortcode_atts( array(
            'form' => '',
            'privacy_url' => '',
            'submit_label' => 'Submit',
            'submit_callback' => '',
            'meta' => '',
            'values' => '',
            'required_marker' => '*'
	), $atts ) );
        
        global $fs_forms_url;
        global $fs_visitor;
        global $fs_form_view_values;
        global $is_IE;
        
        $this->required_marker = $required_marker;
        
        wp_enqueue_script('jquery-ui-1.10.3.custom.min.js');  
        wp_enqueue_script('jquery.form.js');   
        wp_enqueue_script('jquery.validate.min.js');   
        wp_enqueue_script('fs-form-view-script.js', $fs_forms_url.'script/fs-form-view-script.js', array('jquery', 'jquery.form.js', 'jquery.validate.min.js'));
        
        if ( $is_IE ) 
        {
            wp_enqueue_script('jquery.placeholder');
            wp_enqueue_script('fs-ie-fix');
        }
        $fields = array (
            "Form" => $form,
        );
        $json = FsForms::CurlGetContents(FsForms::$form_schema_script, $fields);
        $schema = json_decode($json);
        
        if($schema->template != null)
        {
            $this->template = $schema->template;
        }
 
        $html = '<div id="fs-form-container-'.$schema->recnum.'" class="fs-form-container">';       
        $action = FsForms::$form_processor_script;
        if(get_option('testing') == 1)
        {
            $action = FsForms::$form_processor_test_script;
        }
        $html .= '<form id="fs-lead-form-'.$schema->recnum.'" action="'.$action.'" method="post">
        <input type="hidden" name="form" value="'.$schema->recnum.'" />
        <input type="hidden" name="type" value="1" />
        <input type="hidden" name="ip_address" value="'.$_SERVER['REMOTE_ADDR'].'" />
        <input type="hidden" name="from_url" value="'.$_SERVER['REQUEST_URI'].'" />     
        <input type="hidden" name="visitor" value="'.$fs_visitor.'" />
        <input type="hidden" name="meta" value="'.$meta.'" />
        <p style="display: none;">
            <input type="text" name="username" />
        </p>';        
        foreach($schema->fields as $field)
        {
            $value = null;
            if(isset($fs_form_view_values) && count($fs_form_view_values)>0)
            {                
                foreach($fs_form_view_values as $v)
                {
                    if($field->name == $v->name)
                    {
                        $value = $v;
                    }                
                }
            }
            $html .= $this->render_field($field, $value);
        }                
        $html.='</form>
        <div id="fs-lead-loader-'.$schema->recnum.'" class="fs-loader"></div>
        <div class="fs-form-row">';
        if(strlen($privacy_url)>0)
        {
            $html .= '<a class="fs-privacy-link" href="'.$privacy_url.'">Privacy Link</a>';
        }
        $html.='<a id="fs-lead-submit-'.$schema->recnum.'" class="fs-lead-submit" href="#">'.$submit_label.'</a>
        </div>
        <div id="fs-lead-result-'.$schema->recnum.'" class="fs-form-row"></div>
        <script type="text/javascript">
        jQuery(document).ready(function() {
            FsAnalytics.FormView('.$schema->recnum.');';
            foreach($schema->fields as $field)
            {
                if($field->type == self::$TextInputType || $field->type == self::$DateInputType)
                {
                    $html.='jQuery(\'#fs-lead-form-'.$schema->recnum.' input[name="'.$field->name.'"]\').change(function(){
                        var value = jQuery(\'#fs-lead-form-'.$schema->recnum.' input[name="'.$field->name.'"]\').val();
                        FsAnalytics.FormUpdate('.$field->recnum.', value);
                    });';
                }
                else if($field->type == self::$TextAreaType)
                {
                    $html.='jQuery(\'#fs-lead-form-'.$schema->recnum.' textarea[name="'.$field->name.'"]\').change(function(){
                        var value = jQuery(\'#fs-lead-form-'.$schema->recnum.' textarea[name="'.$field->name.'"]\').val();
                        FsAnalytics.FormUpdate('.$field->recnum.', value);
                     });';
                }
            }
        
            $html .= '
            jQuery("#fs-lead-submit-'.$schema->recnum.'").click(function(){
                jQuery("#fs-lead-form-'.$schema->recnum.'").submit();
                return false;
            });
            jQuery("#fs-lead-form-'.$schema->recnum.'").validate({
                rules: {';                    
            $rules = array();
            foreach($schema->fields as $field)
            {
                $rule =  $field->name.': {';
                if($field->required==1)
                {
                     $rule .= 'required: true';
                }
                $rule .= '}';
                $rules[] = $rule;
            }
            $html .= implode(',',$rules);  
            $html .= '},
                messages: {';
            $messages = array();
            foreach($schema->fields as $field)
            {
                if($field->required==1)
                {
                    $messages[] = $field->name.': "*"';
                }
            }
            $html .= implode(',', $messages);
            $html .= '},
                submitHandler: function(form) {
                    jQuery(form).ajaxSubmit({
                            target: "#fs-lead-result-'.$schema->recnum.'",                            
                            beforeSubmit: function() {
                                jQuery("#fs-lead-submit-'.$schema->recnum.'").hide();
                                jQuery("#fs-lead-loader-'.$schema->recnum.'").show();
                            },
                            success: function() {
                                jQuery("#fs-lead-submit-'.$schema->recnum.'").show();
                                jQuery("#fs-lead-loader-'.$schema->recnum.'").hide();
                                '.$submit_callback.'
                            },
                            error: function(jqXHR, textStatus, errorThrown) {
                                jQuery("#fs-lead-submit-'.$schema->recnum.'").show();
                                jQuery("#fs-lead-loader-'.$schema->recnum.'").hide();
                                jQuery("#fs-lead-result-'.$schema->recnum.'").html(jqXHR.status+"<br/>"+jqXHR.statusText);
                          }
                    });
                }
            });
        });
        </script>';
        $html .= '</div>';
        return $html;
    }
    
    private function render_field($field, $value=null)
    {
        $html = '';
        if($value != null)
        {
            $html .= '<input type="hidden" name="'.$field->name.'" value="'.$value->value.'" />';
        }        
        else
        {
            switch($field->type)
            {
                case self::$TextInputType:
                    $html = $this->render_text_input_field($field, $value);
                    break;
                case self::$TextAreaType:
                    $html = $this->render_textarea_field($field, $value);
                    break;
                case self::$CheckInputsType:
                    $html = $this->render_checks_input_field($field, $value);
                    break;
                case self::$RadioInputsType:
                    $html = $this->render_radios_input_field($field, $value);
                    break;
                case self::$DateInputType:
                    $html = $this->render_date_input_field($field, $value);
                    break;
            }
        }
        return $html;
    }
    private function render_text_input_field($field)
    {    
        if($field->required==1 && strlen($this->required_marker)>0)
        {
            $field->title.=(' '.$this->required_marker);
        }
        $html = '<div class="fs-form-row fs-text-row">';        
        if($this->template != null && $this->template->label_type == self::$OutsideLabelType)
        {
            $html .= '<label for="'.$field->name.'-'.$field->recnum.'-input">'.$field->title.'</label><input type="text" id="'.$field->name.'-'.$field->recnum.'-input" name="'.$field->name.'"  />';
        }
        else
        {
            $html .= '<input type="text" id="'.$field->name.'-'.$field->recnum.'-input" name="'.$field->name.'" placeholder="'.$field->title.'"  />';
        }    
        $html .= '</div>';
        return $html;
    }
    private function render_textarea_field($field)
    {
        $html = '<div class="fs-form-row fs-textarea-row">';
        if($this->template != null && $this->template->label_type == self::$OutsideLabelType)
        {
            $html .= '<label for="'.$field->name.'-'.$field->recnum.'-textarea">'.$field->title.'</label><textarea id="'.$field->name.'-'.$field->recnum.'-textarea" name="'.$field->name.'"></textarea>';
        }
        else
        {
            $html .= '<textarea id="'.$field->name.'-'.$field->recnum.'-textarea" name="'.$field->name.'" placeholder="'.$field->title.'"></textarea>';
        }
        $html .= '</div>';
        return $html;
    }
    private function render_checks_input_field($field)
    {
        $html = '<div class="fs-form-row fs-checks-row">
            <label>'.$field->title.'</label>
            <div class="fs-check-options">';
            $i=0;
            foreach($field->meta->select_options as $option)
            {
                $checked = '';
                $html .= '<input type="checkbox" name="'.$field->name.'[]" value="'.$option->value.'" '.$checked.' />'.$option->label.'<br/>';
                $i++;
            }            
            $html .= '</div>
        </div>';
        return $html;
    }
    private function render_radios_input_field($field)
    {
        $html = '<div class="fs-form-row fs-radios-row">
            <label>'.$field->title.'</label>
            <div class="fs-radio-options">';            
            foreach($field->meta->select_options as $option)
            {
                $checked = '';
                $html .= '<div class="fs-radio-option"><input type="radio" name="'.$field->name.'" value="'.$option->value.'" '.$checked.' />'.$option->label.'</div>';
            }            
            $html .= '</div>
        </div>';
        return $html;
    }
    private function render_date_input_field($field)
    {    
        if($field->required==1 && strlen($this->required_marker)>0)
        {
            $field->title.=(' '.$this->required_marker);
        }
        $html = '<div class="fs-form-row fs-text-row fs-date-row">';
        if($this->template != null && $this->template->label_type == self::$OutsideLabelType)
        {
            $html .= '<label for="'.$field->name.'-'.$field->recnum.'-input">'.$field->title.'</label><input type="text" id="'.$field->name.'-'.$field->recnum.'-input" name="'.$field->name.'"  />';
        }
        else
        {
            $html .= '<input type="text" id="'.$field->name.'-'.$field->recnum.'-input" name="'.$field->name.'" placeholder="'.$field->title.'"  />';
        }    
        $html .= '</div>';
        return $html;
    }
    

 
}

?>
